==> aidlab_sdk-0.0.1.tar.gz: lib/src/api/aidlab_delegate.dart <==

import 'body_position.dart';
import 'wear_state.dart';

import 'activity_type.dart';
import 'aidlab.dart';
import 'exercise.dart';

abstract class AidlabDelegate {

  void didConnectAidlab(Aidlab aidlab);

  void didDisconnectAidlab(Aidlab aidlab);

  void didReceiveECG(Aidlab aidlab, int timestamp, List<double> values);

  void didReceiveRespiration(Aidlab aidlab, int timestamp, List<double> values);

  void didReceiveRespirationRate(Aidlab aidlab, int timestamp, int value);

  void didReceiveBatteryLevel(Aidlab aidlab, int stateOfCharge);

  void didReceiveSkinTemperature(Aidlab aidlab, int timestamp, double value);

  void didReceiveAccelerometer(Aidlab aidlab, int timestamp, double ax, double ay, double az);

  void didReceiveGyroscope(Aidlab aidlab, int timestamp, double qx, double qy, double qz);

  void didReceiveMagnetometer(Aidlab aidlab, int timestamp, double mx, double my, double mz);

  void didReceiveQuaternion(Aidlab aidlab, int timestamp, double qw, double qx, double qy, double qz);

  void didReceiveOrientation(Aidlab aidlab, int timestamp, double roll, double pitch, double yaw, BodyPosition bodyPosition);

  void didReceiveActivity(Aidlab aidlab, int timestamp, ActivityType activity);

  void didReceiveSteps(Aidlab aidlab, int timestamp, int steps);

  void didReceiveHeartRate(Aidlab aidlab, int timestamp, List<int> hrv, int heartRate);

  void wearStateDidChange(Aidlab aidlab, WearState wearState);

  void didDetectExercise(Aidlab aidlab, Exercise exercise);

  void didReceiveSoundVolume(Aidlab aidlab, int timestamp, int value);

  void didReceiveCommand(Aidlab aidlab);

  void didReceiveError(String error);

  void didReceiveFirmwareInformation(bool updateAvaible, String updatableVersion);

  void didReceivePressure(Aidlab aidlab, int timestamp, List<int> values);

  void pressureWearStateDidChange(Aidlab aidlab, WearState state);

  void didReceiveMessage(Aidlab aidlab, String process, String message);
}

==> aidlab_sdk-0.0.3.tar.gz: lib/src/api/aidlab_delegate.dart <==
import 'body_position.dart';
import 'wear_state.dart';

import 'activity_type.dart';
import 'aidlab.dart';
import 'exercise.dart';

abstract class AidlabDelegate {
  void didConnectAidlab(Aidlab aidlab);

  void didDisconnectAidlab(Aidlab aidlab);

  void didReceiveECG(Aidlab aidlab, int timestamp, List<double> values);

  void didReceiveRespiration(Aidlab aidlab, int timestamp, List<double> values);

  void didReceiveRespirationRate(Aidlab aidlab, int timestamp, int value);

  void didReceiveBatteryLevel(Aidlab aidlab, int stateOfCharge);

  void didReceiveSkinTemperature(Aidlab aidlab, int timestamp, double value);

  void didReceiveAccelerometer(
      Aidlab aidlab, int timestamp, double ax, double ay, double az);

  void didReceiveGyroscope(
      Aidlab aidlab, int timestamp, double qx, double qy, double qz);

  void didReceiveMagnetometer(
      Aidlab aidlab, int timestamp, double mx, double my, double mz);

  void didReceiveQuaternion(
      Aidlab aidlab, int timestamp, double qw, double qx, double qy, double qz);

  void didReceiveOrientation(Aidlab aidlab, int timestamp, double roll,
      double pitch, double yaw, BodyPosition bodyPosition);

  void didReceiveActivity(Aidlab aidlab, int timestamp, ActivityType activity);

  void didReceiveSteps(Aidlab aidlab, int timestamp, int steps);

  void didReceiveHeartRate(
      Aidlab aidlab, int timestamp, List<int> hrv, int heartRate);

  void wearStateDidChange(Aidlab aidlab, WearState wearState);

  void didDetectExercise(Aidlab aidlab, Exercise exercise);

  void didReceiveSoundVolume(Aidlab aidlab, int timestamp, int value);

  void didReceiveCommand(Aidlab aidlab);

  void didReceiveError(String error);

  void didReceiveMessage(Aidlab aidlab, String process, String message);
}
